/****************************************************************************
** Meta object code from reading C++ file 'x11worker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-personalization/operation/x11worker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'x11worker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9X11WorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto X11Worker::qt_create_metaobjectdata<qt_meta_tag_ZN9X11WorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "X11Worker",
        "setTitleBarHeight",
        "",
        "value",
        "setWindowEffect",
        "setMovedWindowOpacity",
        "setMiniEffect",
        "effect",
        "setWallpaperForMonitor",
        "screen",
        "url",
        "isDark",
        "PersonalizationExport::WallpaperSetOption",
        "option",
        "PersonalizationExport::WallpaperType",
        "type",
        "setBackgroundForMonitor",
        "screenName",
        "setLockBackForMonitor",
        "onMiniEffectChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setTitleBarHeight'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setWindowEffect'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setMovedWindowOpacity'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'setMiniEffect'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setWallpaperForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool, PersonalizationExport::WallpaperSetOption, PersonalizationExport::WallpaperType)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::Bool, 11 }, { 0x80000000 | 12, 13 },
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setBackgroundForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool, PersonalizationExport::WallpaperType)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 10 }, { QMetaType::Bool, 11 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setBackgroundForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Slot 'setLockBackForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool, PersonalizationExport::WallpaperType)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 10 }, { QMetaType::Bool, 11 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setLockBackForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Slot 'onMiniEffectChanged'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<X11Worker, qt_meta_tag_ZN9X11WorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject X11Worker::staticMetaObject = { {
    QMetaObject::SuperData::link<PersonalizationWorker::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9X11WorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9X11WorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9X11WorkerE_t>.metaTypes,
    nullptr
} };

void X11Worker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<X11Worker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setTitleBarHeight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->setWindowEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->setMovedWindowOpacity((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->setMiniEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->setWallpaperForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<PersonalizationExport::WallpaperSetOption>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<PersonalizationExport::WallpaperType>>(_a[5]))); break;
        case 5: _t->setBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<PersonalizationExport::WallpaperType>>(_a[4]))); break;
        case 6: _t->setBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 7: _t->setLockBackForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<PersonalizationExport::WallpaperType>>(_a[4]))); break;
        case 8: _t->setLockBackForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 9: _t->onMiniEffectChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *X11Worker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *X11Worker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9X11WorkerE_t>.strings))
        return static_cast<void*>(this);
    return PersonalizationWorker::qt_metacast(_clname);
}

int X11Worker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PersonalizationWorker::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
